@@ -36,8 +36,8 @@ inp_files = [
 "t22.abi",
 "t23.abi",
 "t24.abi",
-"t34.abi",
-"t35.abi",
+"-t34.abi", # Disabled
+"-t35.abi", # Disabled
 "t41.abi",
 "t42.abi", 
 "t43.abi", 
